@@ -7,31 +7,13 @@ import subprocess
 import sys
 from argparse import ArgumentParser, Namespace, RawDescriptionHelpFormatter
 from datetime import datetime, timezone
-from pathlib import Path
 
 from connector.httpx_rewrite import proxy_settings
+from connector.logging import set_logger_config
 from connector.oai.integration import Integration
 from connector.pydantic import get_pydantic_model
 from connector.utils import proxy_utils
 
-# file log
-now = datetime.now(timezone.utc)
-daily_rotation = now.strftime("%Y-%m-%d")
-logs_dir = Path("logs")
-logs_dir.mkdir(exist_ok=True)
-logging.basicConfig(
-    filename=str(logs_dir.joinpath(f"all_commands_{daily_rotation}.log")),
-    filemode="a",
-    format="%(asctime)s,%(msecs)d %(name)s %(levelname)s %(message)s",
-    datefmt="%H:%M:%S",
-    level=logging.INFO,
-)
-# console log (stderr only to not interfere with stdout command output)
-console = logging.StreamHandler(sys.stderr)
-console.setLevel(logging.INFO)
-console.setFormatter(logging.Formatter("%(levelname)-9s %(message)s"))
-logging.getLogger().addHandler(console)
-
 logger = logging.getLogger("integration-connectors.sdk")
 
 # Hacking commands
@@ -99,7 +81,7 @@ def create_integration_hacking_parser(integration: Integration, parser: Argument
         "--reload", action="store_true", help="Enable hot reload for the server."
     )
     http_server_parser.add_argument(
-        "--use-proxy", action="store_true", help="Use the Lumos SIP to proxy requests."
+        "--use-proxy", "--sip", action="store_true", help="Use the Lumos SIP to proxy requests."
     )
     http_server_parser.set_defaults(
         func=lambda args: http_integration_server(integration, **_prep_hacking_command(args))
@@ -212,27 +194,10 @@ def collect_capabilities(integration: Integration, no_print: bool = False) -> Ar
 """,
     )
 
-    parser.add_argument(
-        "-p",
-        "--use-proxy",
-        action="store_true",
-        help="Use the Lumos SIP to proxy requests.",
-    )
-
     subparsers = parser.add_subparsers(dest="command")
 
     subparser = subparsers.add_parser("info", description=integration.info.__doc__)
-    subparser.add_argument(
-        "--result-file-path",
-        type=str,
-        help=(
-            "The path to the file to save the result to. If this file already exists, its "
-            "content will be overwritten. If not provided, the result will be printed to the "
-            "console. The result file will be gzip compressed so the input file name should "
-            "end with the .gz extension."
-        ),
-        default=None,
-    )
+    _add_arguments_to_subparser(subparser)
     subparser.set_defaults(func=lambda args: capability_executor(integration, args))
 
     for capability_name, capability in integration.capabilities.items():
@@ -244,17 +209,7 @@ def collect_capabilities(integration: Integration, no_print: bool = False) -> Ar
             pass
         else:
             subparser.add_argument("--json", type=str, help="JSON input", required=True)
-            subparser.add_argument(
-                "--result-file-path",
-                type=str,
-                help=(
-                    "The path to the file to save the result to. If this file already exists, "
-                    "its content will be overwritten. If not provided, the result will be "
-                    "printed to the console. The result file will be gzip compressed so the "
-                    "input file name should end with the .gz extension."
-                ),
-                default=None,
-            )
+            _add_arguments_to_subparser(subparser)
 
         subparser.set_defaults(func=lambda args: capability_executor(integration, args))
 
@@ -264,11 +219,32 @@ def collect_capabilities(integration: Integration, no_print: bool = False) -> Ar
     return parser
 
 
+def _add_arguments_to_subparser(subparser: ArgumentParser):
+    subparser.add_argument(
+        "--result-file-path",
+        type=str,
+        help=(
+            "The path to the file to save the result to. If this file already exists, "
+            "its content will be overwritten. If not provided, the result will be "
+            "printed to the console. The result file will be gzip compressed so the "
+            "input file name should end with the .gz extension."
+        ),
+        default=None,
+    )
+    subparser.add_argument(
+        "--use-proxy",
+        "--sip",
+        action="store_true",
+        help="Use the Lumos SIP to proxy requests. This should not be used by non-Lumos developers.",
+    )
+
+
 def run_integration(
     integration: Integration,
     no_print: bool = False,
 ) -> None:
-    logger.info("Running command started at %s", datetime.now())
+    set_logger_config(integration.app_id)
+    logger.info("Running command started at %s", datetime.now(timezone.utc))
     try:
         """Run a command from the CLI, integration version."""
         parser = collect_capabilities(integration, no_print)
@@ -285,4 +261,4 @@ def run_integration(
         )
         logger.error("Stack trace:", exc_info=True)
         raise e
-    logger.info("Command completed at %s", datetime.now())
+    logger.info("Command completed at %s", datetime.now(timezone.utc))
