@@ -1,7 +1,8 @@
 import logging
 import traceback
 from abc import abstractmethod
-from typing import Any, Callable, List, Tuple
+from collections.abc import Callable
+from typing import Any
 
 from connector.generated import Error, ErrorCode, ErrorResponse
 
@@ -74,15 +75,43 @@ class DefaultHandler(ExceptionHandler):
         logger.debug(e, exc_info=True)
         status_code: int | None = None
 
-        # HTTPX HTTP Status code
+        # HTTPX HTTP Status code / message
         if hasattr(e, "response") and hasattr(e.response, "status_code"):  # type: ignore
             status_code = e.response.status_code  # type: ignore
         # GraphQL error code
         if hasattr(e, "code"):
             status_code = e.code  # type: ignore
 
+        # Attempt to extract error message from response
+        response_message = None
+        try:
+            error_data = e.response.json()  # type: ignore
+            if error_data and not (isinstance(error_data, dict | list) and len(error_data) == 0):
+                if hasattr(e, "response") and hasattr(e.response, "url"):  # type: ignore
+                    response_message = (
+                        f"[{status_code}][{str(e.response.url).split('?')[0]}] {str(error_data)}"  # type: ignore
+                    )
+                else:
+                    response_message = f"[{status_code}] {str(error_data)}"
+        except Exception:
+            if hasattr(e, "response") and hasattr(e.response, "text"):  # type: ignore
+                if hasattr(e.response, "url") and hasattr(e.response, "status_code"):  # type: ignore
+                    response_message = (
+                        f"[{e.response.status_code}][{str(e.response.url).split('?')[0]}] {e.response.text}"  # type: ignore
+                        if e.response.text  # type: ignore
+                        else None
+                    )
+                else:
+                    response_message = e.response.text or None  # type: ignore
+            else:
+                response_message = str(e.message) if hasattr(e, "message") else str(e)  # type: ignore
+
         # Populating some base info
-        response.error.message = e.message if hasattr(e, "message") else str(e)  # type: ignore
+        if "response_message" in locals() and response_message:
+            response.error.message = response_message
+        else:
+            response.error.message = e.message if hasattr(e, "message") else str(e)  # type: ignore
+
         response.error.status_code = status_code
         # TODO: add line number
         response.error.raised_in = f"{original_func.__module__}:{original_func.__name__}"
@@ -129,7 +158,7 @@ class HTTPHandler(ExceptionHandler):
         return response
 
 
-ErrorMap = List[Tuple[type[Exception], type[ExceptionHandler], ErrorCode | None]]
+ErrorMap = list[tuple[type[Exception], type[ExceptionHandler], ErrorCode | None]]
 
 
 def handle_exception(
