@@ -36,8 +36,10 @@ from pydantic import BaseModel, ValidationError
 from connector.generated import (
     AppCategory,
     AuthCredential,
+    AuthModel,
     BasicCredential,
     CapabilitySchema,
+    CredentialConfig,
     EntitlementType,
     Error,
     ErrorCode,
@@ -45,6 +47,7 @@ from connector.generated import (
     Info,
     InfoResponse,
     JWTCredential,
+    OAuth1Credential,
     OAuthClientCredential,
     OAuthCredential,
     ResourceType,
@@ -53,23 +56,35 @@ from connector.generated import (
 )
 from connector.oai.capability import (
     CapabilityCallableProto,
-    capability_requires_auth,
+    capability_requires_authentication,
     generate_capability_schema,
     get_capability_annotations,
     validate_capability,
 )
 from connector.oai.errors import ErrorMap, handle_exception
 from connector.oai.modules.base_module import BaseIntegrationModule
+from connector.oai.modules.info_module import InfoModule
 from connector.oai.modules.oauth_module import OAuthModule
-from connector.oai.modules.oauth_module_types import OAuthSettings
+from connector.oai.modules.oauth_module_types import OAuthConfig, OAuthSettings
+
+AuthSetting: t.TypeAlias = (
+    type[OAuthCredential]
+    | type[OAuthClientCredential]
+    | type[OAuth1Credential]
+    | type[BasicCredential]
+    | type[TokenCredential]
+    | type[JWTCredential]
+)
+
+
+AUTH_TYPE_MAP = {
+    AuthModel.OAUTH: OAuthCredential,
+    AuthModel.OAUTH_CLIENT_CREDENTIALS: OAuthClientCredential,
+    AuthModel.BASIC: BasicCredential,
+    AuthModel.TOKEN: TokenCredential,
+    AuthModel.JWT: JWTCredential,
+}
 
-AuthSetting: t.TypeAlias = t.Union[
-    t.Type[OAuthCredential],
-    t.Type[OAuthClientCredential],
-    t.Type[BasicCredential],
-    t.Type[TokenCredential],
-    t.Type[JWTCredential],
-]
 
 logger = logging.getLogger("integration-connectors.sdk")
 
@@ -102,7 +117,7 @@ class InvalidCapabilityNameError(IntegrationError):
     Raised when registering a custom capability, using a name that violates our naming conventions
     """
 
-    def __init__(self, capability_name: str, reason: t.Optional[str]) -> None:
+    def __init__(self, capability_name: str, reason: str | None) -> None:
         msg = f"Cannot register {capability_name} as a custom capability."
         if reason is None:
             msg += (
@@ -160,7 +175,7 @@ def _validate_capability_name(capability_name: str) -> None:
 
 class Integration:
     app_id: str
-    settings_model: t.Type[BaseModel]
+    settings_model: type[BaseModel]
 
     def __init__(
         self,
@@ -168,17 +183,19 @@ class Integration:
         app_id: str,
         version: str,
         exception_handlers: ErrorMap,
-        auth: AuthSetting,
         description_data: DescriptionData,
+        auth: AuthSetting | None = None,
+        credentials: t.Sequence[CredentialConfig | OAuthConfig] | None = None,
         handle_errors: bool = True,
         resource_types: list[ResourceType] | None = None,
         entitlement_types: list[EntitlementType] | None = None,
-        settings_model: t.Type[BaseModel] | None = None,
+        settings_model: type[BaseModel] | None = None,
         oauth_settings: OAuthSettings | None = None,
     ):
         self.app_id = app_id.strip()
         self.version = version
         self.auth = auth
+        self.credentials = credentials or []
         self.exception_handlers = exception_handlers
         self.handle_errors = handle_errors
         self.description_data = description_data
@@ -194,8 +211,21 @@ class Integration:
         self.capability_metadata: dict[str, CapabilityMetadata] = {}
         self.modules: list[BaseIntegrationModule] = []
 
-        if self.oauth_settings:
-            self.add_module(OAuthModule())
+        # Add OAuthModule if credentials contain OAuthConfig
+        if self.credentials and any(isinstance(cred, OAuthConfig) for cred in self.credentials):
+            oauth_credentials = [
+                cred
+                for cred in self.credentials
+                if isinstance(cred, OAuthConfig) and cred.oauth_settings is not None
+            ]
+            self.add_module(OAuthModule(oauth_credentials))
+        else:
+            # Add OAuthModule if oauth_settings is provided (backwards compatibility, until phasing 'auth' out)
+            if self.oauth_settings is not None:
+                self.add_module(OAuthModule([self.oauth_settings]))
+
+        # Attach the info module (app_info capability)
+        self.add_module(InfoModule())
 
     def add_module(self, module: BaseIntegrationModule):
         self.modules.append(module)
@@ -346,8 +376,164 @@ class Integration:
                 ).model_dump_json()
             raise NotImplementedError from None
 
+        # JSON Input
         json_object = json.loads(request_string)
-        if json_object and "auth" in json_object:
+        if not json_object:
+            return ErrorResponse(
+                is_error=True,
+                error=Error(
+                    message="Invalid request, expected JSON input.",
+                    error_code=ErrorCode.BAD_REQUEST,
+                    app_id=self.app_id,
+                ),
+            ).model_dump_json()
+
+        # Is this a call to the app_info capability?
+        is_app_info_call = name == StandardCapabilityName.APP_INFO.value
+
+        # Credentials parameter validation
+        validated_credentials = False
+        if "credentials" in json_object and json_object["credentials"] is not None:
+            """
+            TypeSpec does not support this level of union oneOf types,
+            hence we do the validation here.
+            At some point in the future, we should just remove 'auth', but for now we are
+            backwards compatible and it is being kept.
+            """
+            if len(json_object["credentials"]) == 0 and self._is_using_credentials():
+                if not is_app_info_call:
+                    return ErrorResponse(
+                        is_error=True,
+                        error=Error(
+                            message="Missing credentials in request",
+                            error_code=ErrorCode.BAD_REQUEST,
+                            app_id=self.app_id,
+                        ),
+                    ).model_dump_json()
+
+            if "auth" in json_object and json_object["auth"] is not None:
+                return ErrorResponse(
+                    is_error=True,
+                    error=Error(
+                        message="Cannot pass credentials and auth in the same request, if you've meant to make this connector multi-auth compatible, please remove the auth field.",
+                        error_code=ErrorCode.BAD_REQUEST,
+                        app_id=self.app_id,
+                    ),
+                ).model_dump_json()
+
+            # Validate the credentials
+            input_credentials: list[AuthCredential] = []
+            try:
+                for index, credential in enumerate(json_object["credentials"]):
+                    auth_credential = AuthCredential.model_validate(credential)
+                    if not auth_credential.id:
+                        return ErrorResponse(
+                            is_error=True,
+                            error=Error(
+                                message=f"Missing ID in credential at index {index}",
+                                error_code=ErrorCode.BAD_REQUEST,
+                                app_id=self.app_id,
+                            ),
+                        ).model_dump_json()
+                    else:
+                        # Validate that we are receiving expected credentials
+                        if auth_credential.id not in [c.id for c in self.credentials]:
+                            return ErrorResponse(
+                                is_error=True,
+                                error=Error(
+                                    message=f"Credential with id '{auth_credential.id}' not expected",
+                                    error_code=ErrorCode.BAD_REQUEST,
+                                    app_id=self.app_id,
+                                ),
+                            ).model_dump_json()
+
+                    input_credentials.append(auth_credential)
+            except ValidationError:
+                return ErrorResponse(
+                    is_error=True,
+                    error=Error(
+                        message="Malformed credentials in request",
+                        error_code=ErrorCode.BAD_REQUEST,
+                        app_id=self.app_id,
+                    ),
+                ).model_dump_json()
+
+            for credential in input_credentials:
+                # Grab its connector counterpart
+                connector_credential = next(
+                    (cred for cred in self.credentials if cred.id == credential.id), None
+                )
+
+                # If the credential is not expected, return an error
+                if connector_credential is None:
+                    return ErrorResponse(
+                        is_error=True,
+                        error=Error(
+                            message=f"Credential with id '{credential.id}' not expected",
+                            error_code=ErrorCode.BAD_REQUEST,
+                            app_id=self.app_id,
+                        ),
+                    ).model_dump_json()
+
+                # If the credential is optional, skip model validation
+                if connector_credential.optional:
+                    logger.info(
+                        f"[{self.app_id}][INFO] Credential with id '{credential.id}' is optional, skipping model validation."
+                    )
+                    continue
+
+                # Validate the credential type
+                missing = "Nothing"
+                if connector_credential.type == AuthModel.BASIC:
+                    if not credential.basic:
+                        missing = "basic"
+                elif connector_credential.type == AuthModel.OAUTH:
+                    if not credential.oauth:
+                        missing = "oauth"
+                elif connector_credential.type == AuthModel.OAUTH_CLIENT_CREDENTIALS:
+                    if not credential.oauth_client_credentials:
+                        missing = "oauth_client_credentials"
+                elif connector_credential.type == AuthModel.TOKEN:
+                    if not credential.token:
+                        missing = "token"
+                elif connector_credential.type == AuthModel.JWT:
+                    if not credential.jwt:
+                        missing = "jwt"
+                if missing != "Nothing":
+                    return ErrorResponse(
+                        is_error=True,
+                        error=Error(
+                            message=f"Missing '{missing}' credential in request",
+                            error_code=ErrorCode.BAD_REQUEST,
+                            app_id=self.app_id,
+                        ),
+                    ).model_dump_json()
+
+            validated_credentials = True
+
+        # TODO: Later on when "auth" is phased out, we can turn this on
+        # elif capability_has_authenticated_request(capability):
+        #    return ErrorResponse(
+        #        is_error=True,
+        #        error=Error(
+        #            message="Missing credentials in request",
+        #            error_code=ErrorCode.BAD_REQUEST,
+        #            app_id=self.app_id,
+        #        ),
+        #    ).model_dump_json()
+
+        # Auth parameter validation
+        if "auth" in json_object and json_object["auth"] is not None:
+            if "credentials" in json_object and json_object["credentials"] is not None:
+                return ErrorResponse(
+                    is_error=True,
+                    error=Error(
+                        message="Cannot pass credentials and auth in the same request, if you've meant to make this connector multi-auth compatible, please remove the auth field.",
+                        error_code=ErrorCode.BAD_REQUEST,
+                        app_id=self.app_id,
+                    ),
+                ).model_dump_json()
+
             try:
                 auth_credential = AuthCredential.model_validate(json_object["auth"])
             except ValidationError:
@@ -375,16 +561,21 @@ class Integration:
                         app_id=self.app_id,
                     ),
                 ).model_dump_json()
-        elif capability_requires_auth(capability):
-            return ErrorResponse(
-                is_error=True,
-                error=Error(
-                    message="Missing auth in request",
-                    error_code=ErrorCode.BAD_REQUEST,
-                    app_id=self.app_id,
-                ),
-            ).model_dump_json()
+        elif capability_requires_authentication(capability) and not validated_credentials:
+            # Since this is not migrated yet, we just flat out skip is_app_info_call
+            # In the future we can re-instate the is_required() checks inside this validation
+            # and make this work for is_app_info_call automatically (its not required for is_app_info_call)
+            if not is_app_info_call:
+                return ErrorResponse(
+                    is_error=True,
+                    error=Error(
+                        message="Missing auth/credentials in request",
+                        error_code=ErrorCode.BAD_REQUEST,
+                        app_id=self.app_id,
+                    ),
+                ).model_dump_json()
 
+        # Capability annotation validation
         request_annotation, _ = get_capability_annotations(capability)
         try:
             request = request_annotation.model_validate(json_object)
@@ -402,14 +593,15 @@ class Integration:
         if self.settings_model == EmptySettings:
             pass
         elif request.settings is None and self.handle_errors:
-            return ErrorResponse(
-                is_error=True,
-                error=Error(
-                    message=f"No settings passed on request: {self.app_id} requires {self.settings_model.__name__}",
-                    error_code=ErrorCode.BAD_REQUEST,
-                    app_id=self.app_id,
-                ),
-            ).model_dump_json()
+            if not is_app_info_call:
+                return ErrorResponse(
+                    is_error=True,
+                    error=Error(
+                        message=f"No settings passed on request: {self.app_id} requires {self.settings_model.__name__}",
+                        error_code=ErrorCode.BAD_REQUEST,
+                        app_id=self.app_id,
+                    ),
+                ).model_dump_json()
         else:
             try:
                 self.settings_model.model_validate(request.settings)
@@ -445,12 +637,11 @@ class Integration:
         interface is returned. The authentication schema is also
         included.
         """
+        logger.debug("Generating info response")
         capability_names = sorted(self.capabilities.keys())
         capability_schema: dict[str, CapabilitySchema] = {}
         for capability_name in capability_names:
-            command_types = generate_capability_schema(
-                capability_name, self.capabilities[capability_name]
-            )
+            command_types = generate_capability_schema(self.capabilities[capability_name])
 
             capability_metadata: CapabilityMetadata | None = None
             if capability_name in self.capability_metadata:
@@ -481,11 +672,14 @@ class Integration:
 
         oauth_scopes = None
         if self.oauth_settings:
-            oauth_scopes = {
-                capability: scope
-                for capability, scope in self.oauth_settings.scopes.items()
-                if scope is not None
-            }
+            if not callable(self.oauth_settings.scopes) and isinstance(
+                self.oauth_settings.scopes, dict
+            ):
+                oauth_scopes = {
+                    capability: scope
+                    for capability, scope in self.oauth_settings.scopes.items()
+                    if scope is not None
+                }
 
         return InfoResponse(
             response=Info(
@@ -500,13 +694,67 @@ class Integration:
                 resource_types=self.resource_types,
                 entitlement_types=self.entitlement_types,
                 request_settings_schema=self.get_model_extended_json_schema(self.settings_model),
-                authentication_schema=self.get_model_extended_json_schema(self.auth),
+                authentication_schema=self.get_model_extended_json_schema(self.auth)
+                if self.auth
+                else {},
+                credentials_schema=self.get_credentials_json_schema() if self.credentials else [],
                 oauth_scopes=oauth_scopes,
             )
         )
 
-    def get_model_extended_json_schema(self, model: t.Type[BaseModel]) -> dict[str, t.Any]:
+    def _is_using_credentials(self) -> bool:
+        return len(self.credentials) > 0
+
+    def get_model_extended_json_schema(self, model: type[BaseModel]) -> dict[str, t.Any]:
         json_schema = model.model_json_schema()
         field_order = list(model.model_fields.keys())
         json_schema["field_order"] = field_order
         return json_schema
+
+    def get_credentials_json_schema(self) -> list[dict[str, t.Any]]:
+        credentials = []
+
+        if self.credentials:
+            for credential in self.credentials:
+                credential_schema = {}
+
+                if credential.input_model:
+                    # Custom input model (override)
+                    credential_schema = self.get_model_extended_json_schema(
+                        t.cast(type[BaseModel], credential.input_model)
+                    )
+                else:
+                    # Standard input model
+                    credential_schema = self.get_model_extended_json_schema(
+                        t.cast(type[BaseModel], AUTH_TYPE_MAP[credential.type])
+                    )
+
+                credential_schema["id"] = credential.id
+                credential_schema["description"] = credential.description
+
+                """
+                Very basic extra oauth_settings info
+                TODO:
+                - The issue here still is that this does not support multiple oauth credentials (not like we need that right now)
+                - This should later be handled exclusively in the new info module and its response
+                """
+                scopes = None
+                if self.oauth_settings:
+                    oauth = self.oauth_settings
+                    if oauth.scopes is not None:
+                        if not callable(oauth.scopes) and isinstance(oauth.scopes, dict):
+                            scopes = {
+                                capability: scope
+                                for capability, scope in oauth.scopes.items()
+                                if scope is not None
+                            }
+
+                    credential_schema["oauth_settings"] = {
+                        "oauth_type": oauth.flow_type,
+                        "scopes": scopes,
+                        "pkce_enabled": oauth.pkce,
+                    }
+
+                credentials.append(credential_schema)
+
+        return credentials
