@@ -22,6 +22,13 @@ class BaseIntegrationModule:
         """Add a capability to the module."""
         self.capabilities.append(capability)
 
+    def get_capability(self, capability: str) -> StandardCapabilityName | str | None:
+        """Get a capability from the module."""
+        for cap in self.capabilities:
+            if cap == capability:
+                return cap
+        return None
+
     @abstractmethod
     def register(self, integration: "Integration"):
         """Register all capabilities of the module / the module."""
