@@ -14,14 +14,6 @@ class MockedResponse:
     ] | None = None  # for cases where we want to match the request body
 
 
-ResponseBodyMap: t.TypeAlias = t.Optional[
-    dict[
-        str,  # http method
-        dict[
-            str,  # url
-            MockedResponse,
-        ],
-    ]
-]
+ResponseBodyMap: t.TypeAlias = dict[str, dict[str, MockedResponse]] | None
 RequestHandler: t.TypeAlias = t.Callable[[httpx.Request], httpx.Response]
 ClientContextManager: t.TypeAlias = t.Callable[[str, str, RequestHandler], t.ContextManager[None]]
