@@ -3,8 +3,10 @@
 import typing as t
 
 from connector.generated import (
+    AuthModel,
     BasicCredential,
     CapabilitySchema,
+    CredentialConfig,
     Info,
     InfoResponse,
     ListAccountsRequest,
@@ -12,13 +14,13 @@ from connector.generated import (
     OAuthCredential,
     StandardCapabilityName,
 )
+from connector.oai.capability import CustomRequest, CustomResponse
 from connector.oai.integration import DescriptionData, Integration
 from connector.oai.modules.oauth_module_types import OAuthSettings
 
 from .shared_types import (
-    AccioRequestObject,
+    AccioRequest,
     AccioResponse,
-    AccioResponseObject,
 )
 
 Case: t.TypeAlias = tuple[
@@ -53,8 +55,8 @@ def case_info() -> Case:
         )
 
     @integration.register_custom_capability("accio", description="A summoning charm.")
-    async def custom_capability(args: AccioRequestObject) -> AccioResponseObject:
-        return AccioResponseObject(
+    async def custom_capability(args: CustomRequest[AccioRequest]) -> CustomResponse[AccioResponse]:
+        return CustomResponse[AccioResponse](
             response=AccioResponse(success=True),
         )
 
@@ -62,7 +64,11 @@ def case_info() -> Case:
         response=Info(
             app_id="test",
             version="0.1.0",
-            capabilities=["accio", StandardCapabilityName.LIST_ACCOUNTS],
+            capabilities=[
+                "accio",
+                StandardCapabilityName.APP_INFO,
+                StandardCapabilityName.LIST_ACCOUNTS,
+            ],
             capability_schema={
                 "accio": CapabilitySchema(
                     argument={
@@ -85,6 +91,37 @@ def case_info() -> Case:
                         "type": "object",
                     },
                 ),
+                StandardCapabilityName.APP_INFO.value: CapabilitySchema(
+                    argument={
+                        "description": "AppInfoRequestPayload",
+                        "properties": {},
+                        "title": "AppInfoRequestPayload",
+                        "type": "object",
+                        "x-capability-category": "specification",
+                    },
+                    description=None,
+                    display_name="App Info",
+                    output={
+                        "description": "AppInfo",
+                        "properties": {
+                            "app_id": {
+                                "title": "App Id",
+                                "type": "string",
+                            },
+                            "app_schema": {
+                                "description": "The connector OpenAPI specification",
+                                "title": "App Schema",
+                                "type": "object",
+                            },
+                        },
+                        "required": [
+                            "app_id",
+                            "app_schema",
+                        ],
+                        "title": "AppInfo",
+                        "type": "object",
+                    },
+                ),
                 StandardCapabilityName.LIST_ACCOUNTS.value: CapabilitySchema(
                     argument={
                         "description": "Request parameters for listing accounts.",
@@ -106,6 +143,7 @@ def case_info() -> Case:
                         },
                         "title": "ListAccounts",
                         "type": "object",
+                        "x-capability-level": "read",
                     },
                     output={"properties": {}, "title": "Empty", "type": "object"},
                     description="List accounts capability description.",
@@ -119,6 +157,7 @@ def case_info() -> Case:
                         "description": "The password for basic auth.",
                         "title": "Password",
                         "type": "string",
+                        "x-field_type": "SECRET",
                     },
                     "username": {
                         "description": "The username for basic auth.",
@@ -133,7 +172,202 @@ def case_info() -> Case:
                 "title": "BasicCredential",
                 "field_order": ["username", "password"],
                 "type": "object",
+                "x-credential-type": "basic",
             },
+            credentials_schema=[],
+            user_friendly_name="test_info_cases.py",
+            categories=[],
+            request_settings_schema={
+                "properties": {},
+                "title": "EmptySettings",
+                "field_order": [],
+                "type": "object",
+            },
+            entitlement_types=[],
+            resource_types=[],
+        )
+    )
+    return integration, expected_info
+
+
+def case_info_with_credentials() -> Case:
+    app_id = "test"
+
+    credentials = [
+        CredentialConfig(
+            id="test",
+            description="Test credential",
+            type=AuthModel.BASIC,
+        ),
+        CredentialConfig(
+            id="test2",
+            description="Test credential 2",
+            type=AuthModel.TOKEN,
+        ),
+    ]
+
+    integration = Integration(
+        app_id=app_id,
+        version="0.1.0",
+        credentials=credentials,
+        exception_handlers=[],
+        handle_errors=True,
+        description_data=DescriptionData(
+            user_friendly_name="test_info_cases.py",
+            categories=[],
+        ),
+    )
+
+    @integration.register_capability(
+        StandardCapabilityName.LIST_ACCOUNTS,
+        description="List accounts capability with credentials description.",
+    )
+    async def capability(
+        args: ListAccountsRequest,
+    ) -> ListAccountsResponse:
+        return ListAccountsResponse(
+            response=[],
+            raw_data=None,
+        )
+
+    @integration.register_custom_capability("accio", description="A summoning charm.")
+    async def custom_capability(args: CustomRequest[AccioRequest]) -> CustomResponse[AccioResponse]:
+        return CustomResponse[AccioResponse](
+            response=AccioResponse(success=True),
+        )
+
+    expected_info = InfoResponse(
+        response=Info(
+            app_id="test",
+            version="0.1.0",
+            capabilities=[
+                "accio",
+                StandardCapabilityName.APP_INFO,
+                StandardCapabilityName.LIST_ACCOUNTS,
+            ],
+            capability_schema={
+                "accio": CapabilitySchema(
+                    argument={
+                        "properties": {
+                            "object_name": {
+                                "title": "Object Name",
+                                "type": "string",
+                            },
+                        },
+                        "required": ["object_name"],
+                        "title": "AccioRequest",
+                        "type": "object",
+                    },
+                    description="A summoning charm.",
+                    display_name="Accio",
+                    output={
+                        "properties": {"success": {"title": "Success", "type": "boolean"}},
+                        "required": ["success"],
+                        "title": "AccioResponse",
+                        "type": "object",
+                    },
+                ),
+                StandardCapabilityName.APP_INFO.value: CapabilitySchema(
+                    argument={
+                        "description": "AppInfoRequestPayload",
+                        "properties": {},
+                        "title": "AppInfoRequestPayload",
+                        "type": "object",
+                        "x-capability-category": "specification",
+                    },
+                    description=None,
+                    display_name="App Info",
+                    output={
+                        "description": "AppInfo",
+                        "properties": {
+                            "app_id": {
+                                "title": "App Id",
+                                "type": "string",
+                            },
+                            "app_schema": {
+                                "description": "The connector OpenAPI specification",
+                                "title": "App Schema",
+                                "type": "object",
+                            },
+                        },
+                        "required": [
+                            "app_id",
+                            "app_schema",
+                        ],
+                        "title": "AppInfo",
+                        "type": "object",
+                    },
+                ),
+                StandardCapabilityName.LIST_ACCOUNTS.value: CapabilitySchema(
+                    argument={
+                        "description": "Request parameters for listing accounts.",
+                        "properties": {
+                            "custom_attributes": {
+                                "anyOf": [
+                                    {"items": {"type": "string"}, "type": "array"},
+                                    {"type": "null"},
+                                ],
+                                "default": None,
+                                "description": (
+                                    "Optional array of custom attribute names to "
+                                    "include in the account data. Each string in "
+                                    "this array represents a specific custom "
+                                    "attribute to retrieve."
+                                ),
+                                "title": "Custom Attributes",
+                            }
+                        },
+                        "title": "ListAccounts",
+                        "type": "object",
+                        "x-capability-level": "read",
+                    },
+                    output={"properties": {}, "title": "Empty", "type": "object"},
+                    description="List accounts capability with credentials description.",
+                    display_name="List Accounts",
+                ),
+            },
+            authentication_schema={},
+            credentials_schema=[
+                {
+                    "id": "test",
+                    "description": "Test credential",
+                    "properties": {
+                        "username": {
+                            "title": "Username",
+                            "description": "The username for basic auth.",
+                            "type": "string",
+                        },
+                        "password": {
+                            "title": "Password",
+                            "description": "The password for basic auth.",
+                            "type": "string",
+                            "x-field_type": "SECRET",
+                        },
+                    },
+                    "required": ["username", "password"],
+                    "title": "BasicCredential",
+                    "field_order": ["username", "password"],
+                    "type": "object",
+                    "x-credential-type": "basic",
+                },
+                {
+                    "id": "test2",
+                    "description": "Test credential 2",
+                    "properties": {
+                        "token": {
+                            "title": "Token",
+                            "description": "The token for token-based auth.",
+                            "type": "string",
+                            "x-field_type": "SECRET",
+                        },
+                    },
+                    "required": ["token"],
+                    "title": "TokenCredential",
+                    "field_order": ["token"],
+                    "type": "object",
+                    "x-credential-type": "token",
+                },
+            ],
             user_friendly_name="test_info_cases.py",
             categories=[],
             request_settings_schema={
@@ -186,16 +420,61 @@ def case_info_with_scopes() -> Case:
             app_id="test",
             version="0.1.0",
             capabilities=[
+                StandardCapabilityName.APP_INFO,
                 StandardCapabilityName.GET_AUTHORIZATION_URL,
                 StandardCapabilityName.HANDLE_AUTHORIZATION_CALLBACK,
                 StandardCapabilityName.LIST_ACCOUNTS,
                 StandardCapabilityName.REFRESH_ACCESS_TOKEN,
             ],
             capability_schema={
+                StandardCapabilityName.APP_INFO.value: CapabilitySchema(
+                    argument={
+                        "description": "AppInfoRequestPayload",
+                        "properties": {},
+                        "title": "AppInfoRequestPayload",
+                        "type": "object",
+                        "x-capability-category": "specification",
+                    },
+                    description=None,
+                    display_name="App Info",
+                    output={
+                        "description": "AppInfo",
+                        "properties": {
+                            "app_id": {
+                                "title": "App Id",
+                                "type": "string",
+                            },
+                            "app_schema": {
+                                "description": "The connector OpenAPI specification",
+                                "title": "App Schema",
+                                "type": "object",
+                            },
+                        },
+                        "required": [
+                            "app_id",
+                            "app_schema",
+                        ],
+                        "title": "AppInfo",
+                        "type": "object",
+                    },
+                ),
                 StandardCapabilityName.GET_AUTHORIZATION_URL.value: CapabilitySchema(
                     argument={
                         "description": "Parameters for generating an OAuth authorization URL.",
                         "properties": {
+                            "credential_id": {
+                                "anyOf": [
+                                    {
+                                        "type": "string",
+                                    },
+                                    {
+                                        "type": "null",
+                                    },
+                                ],
+                                "default": None,
+                                "description": "The credential ID assigned to these credentials.",
+                                "title": "Credential Id",
+                            },
                             "client_id": {
                                 "description": (
                                     "OAuth client ID provided by the third-party service."
@@ -235,6 +514,7 @@ def case_info_with_scopes() -> Case:
                         "required": ["client_id", "scopes", "redirect_uri", "state"],
                         "title": "GetAuthorizationUrl",
                         "type": "object",
+                        "x-capability-category": "authorization",
                     },
                     output={
                         "description": "OAuth authorization URL details.",
@@ -265,6 +545,19 @@ def case_info_with_scopes() -> Case:
                     argument={
                         "description": "Parameters for handling an OAuth2 authorization callback.",
                         "properties": {
+                            "credential_id": {
+                                "anyOf": [
+                                    {
+                                        "type": "string",
+                                    },
+                                    {
+                                        "type": "null",
+                                    },
+                                ],
+                                "default": None,
+                                "description": "The credential ID assigned to these credentials.",
+                                "title": "Credential Id",
+                            },
                             "client_id": {
                                 "description": (
                                     "The OAuth client ID provided by the third-party service."
@@ -308,6 +601,7 @@ def case_info_with_scopes() -> Case:
                         "required": ["client_id", "client_secret", "redirect_uri_with_code"],
                         "title": "HandleAuthorizationCallback",
                         "type": "object",
+                        "x-capability-category": "authorization",
                     },
                     output={
                         "$defs": {
@@ -382,6 +676,7 @@ def case_info_with_scopes() -> Case:
                         },
                         "title": "ListAccounts",
                         "type": "object",
+                        "x-capability-level": "read",
                     },
                     output={"properties": {}, "title": "Empty", "type": "object"},
                     description="List accounts capability description.",
@@ -391,6 +686,19 @@ def case_info_with_scopes() -> Case:
                     argument={
                         "description": "RefreshAccessToken Model",
                         "properties": {
+                            "credential_id": {
+                                "anyOf": [
+                                    {
+                                        "type": "string",
+                                    },
+                                    {
+                                        "type": "null",
+                                    },
+                                ],
+                                "default": None,
+                                "description": "The credential ID assigned to these credentials.",
+                                "title": "Credential Id",
+                            },
                             "client_id": {
                                 "description": (
                                     "The OAuth client ID provided by the third-party service."
@@ -425,6 +733,7 @@ def case_info_with_scopes() -> Case:
                         "required": ["client_id", "client_secret", "refresh_token"],
                         "title": "RefreshAccessToken",
                         "type": "object",
+                        "x-capability-category": "authorization",
                     },
                     output={
                         "$defs": {
@@ -490,13 +799,16 @@ def case_info_with_scopes() -> Case:
                         "description": "The OAuth access token.",
                         "title": "Access Token",
                         "type": "string",
+                        "x-field_type": "HIDDEN",
                     },
                 },
                 "required": ["access_token"],
                 "title": "OAuthCredential",
                 "field_order": ["access_token"],
                 "type": "object",
+                "x-credential-type": "oauth",
             },
+            credentials_schema=[],
             oauth_scopes={
                 "list_accounts": "test:scope another:scope",
             },
