@@ -48,9 +48,9 @@ async def test_register_module_capabilities(
 ) -> None:
     integration.add_module(module)
 
-    print(module.capabilities)
-    print(module)
-
     assert integration.capabilities[StandardCapabilityName.VALIDATE_CREDENTIALS] is not None
-    assert integration.info().response.capabilities == [StandardCapabilityName.VALIDATE_CREDENTIALS]
+    assert integration.info().response.capabilities == [
+        StandardCapabilityName.APP_INFO,
+        StandardCapabilityName.VALIDATE_CREDENTIALS,
+    ]
     assert module.capabilities == [StandardCapabilityName.VALIDATE_CREDENTIALS]
