@@ -3,12 +3,14 @@ from urllib.parse import parse_qs, urlparse
 
 import pytest
 from connector.generated import (
+    AuthModel,
     GetAuthorizationUrl,
     GetAuthorizationUrlRequest,
     HandleAuthorizationCallback,
     HandleAuthorizationCallbackRequest,
     HandleClientCredentials,
     HandleClientCredentialsRequest,
+    OAuthClientCredential,
     OAuthCredential,
     RefreshAccessToken,
     RefreshAccessTokenRequest,
@@ -16,17 +18,19 @@ from connector.generated import (
 )
 from connector.httpx_rewrite import AsyncClient
 from connector.oai.capability import AuthRequest, get_settings
+from connector.oai.errors import ConnectorError
 from connector.oai.integration import DescriptionData, Integration
 from connector.oai.modules.oauth_module import OAuthModule
 from connector.oai.modules.oauth_module_types import (
     ClientAuthenticationMethod,
+    OAuthConfig,
     OAuthFlowType,
     OAuthRequest,
     OAuthSettings,
     RequestDataType,
     RequestMethod,
 )
-from httpx import HTTPStatusError, Request, Response
+from httpx import Request, Response
 from pydantic import BaseModel, ValidationError
 
 
@@ -34,12 +38,37 @@ class Settings(BaseModel):
     subdomain: str
 
 
+INTEGRATION_OAUTH_SETTINGS = OAuthSettings(
+    authorization_url="https://example.com/auth",
+    token_url="https://example.com/token",
+    scopes={
+        StandardCapabilityName.VALIDATE_CREDENTIALS: "test:scope another:scope",
+        StandardCapabilityName.LIST_ACCOUNTS: "test:scope another:scope",
+    },
+)
+
+INTEGRATION_OAUTH_SETTINGS_2 = OAuthSettings(
+    authorization_url="https://example.com/auth2",
+    token_url="https://example.com/token2",
+    scopes={},
+)
+
+CLIENT_CREDENTIALS_INTEGRATION_OAUTH_SETTINGS = OAuthSettings(
+    flow_type=OAuthFlowType.CLIENT_CREDENTIALS,
+    token_url="https://example.com/token",
+    scopes={
+        StandardCapabilityName.VALIDATE_CREDENTIALS: "test:scope another:scope",
+        StandardCapabilityName.LIST_ACCOUNTS: "test:scope another:scope",
+    },
+)
+
+
 @pytest.fixture
 def settings():
     return Settings(subdomain="test")
 
 
-@pytest.fixture
+@pytest.fixture()
 def integration():
     """
     FIXTURE: Create an integration with an OAuthModule
@@ -50,38 +79,83 @@ def integration():
         version="0.1.0",
         exception_handlers=[],
         settings_model=Settings,
-        oauth_settings=OAuthSettings(
-            authorization_url="https://example.com/auth",
-            token_url="https://example.com/token",
-            scopes={
-                StandardCapabilityName.VALIDATE_CREDENTIALS: "test:scope another:scope",
-                StandardCapabilityName.LIST_ACCOUNTS: "test:scope another:scope",
-            },
-        ),
+        oauth_settings=INTEGRATION_OAUTH_SETTINGS,
         description_data=DescriptionData(user_friendly_name="test_oauth_module.py", categories=[]),
     )
 
 
-@pytest.fixture
+@pytest.fixture()
 def client_credentials_integration():
+    """
+    FIXTURE: Create an integration with an OAuthModule configured with a client credentials flow
+    """
     return Integration(
         app_id="test_app",
-        auth=OAuthCredential,
+        auth=OAuthClientCredential,
         version="0.1.0",
         exception_handlers=[],
         settings_model=Settings,
-        oauth_settings=OAuthSettings(
-            flow_type=OAuthFlowType.CLIENT_CREDENTIALS,
-            token_url="https://example.com/token",
-            scopes={
-                StandardCapabilityName.VALIDATE_CREDENTIALS: "test:scope another:scope",
-                StandardCapabilityName.LIST_ACCOUNTS: "test:scope another:scope",
-            },
-        ),
+        oauth_settings=CLIENT_CREDENTIALS_INTEGRATION_OAUTH_SETTINGS,
         description_data=DescriptionData(user_friendly_name="test_oauth_module.py", categories=[]),
     )
 
 
+@pytest.fixture()
+def integration_with_credentials():
+    """
+    FIXTURE: Create an integration that uses OAuthModule through the credentials configs
+    """
+    return Integration(
+        app_id="test_app",
+        credentials=[
+            OAuthConfig(
+                id="test_credential",
+                type=AuthModel.OAUTH,
+                description="Test credential",
+                oauth_settings=INTEGRATION_OAUTH_SETTINGS,
+            ),
+            OAuthConfig(
+                id="test_credential_2",
+                type=AuthModel.OAUTH,
+                description="Test credential 2",
+                oauth_settings=INTEGRATION_OAUTH_SETTINGS_2,
+            ),
+        ],
+        version="0.1.0",
+        exception_handlers=[],
+        settings_model=Settings,
+        description_data=DescriptionData(user_friendly_name="test_oauth_module.py", categories=[]),
+    )
+
+
+@pytest.fixture(autouse=True)
+def cleanup_integration(integration, client_credentials_integration):
+    """
+    FIXTURE: Cleanup the integrations before each test is run
+    """
+    integration.oauth_settings = INTEGRATION_OAUTH_SETTINGS
+    client_credentials_integration.oauth_settings = CLIENT_CREDENTIALS_INTEGRATION_OAUTH_SETTINGS
+
+    integration.auth = OAuthCredential
+    client_credentials_integration.auth = OAuthClientCredential
+    integration_with_credentials.credentials = [
+        OAuthConfig(
+            id="test_credential",
+            type=AuthModel.OAUTH,
+            description="Test credential",
+            oauth_settings=INTEGRATION_OAUTH_SETTINGS,
+        ),
+        OAuthConfig(
+            id="test_credential_2",
+            type=AuthModel.OAUTH,
+            description="Test credential 2",
+            oauth_settings=INTEGRATION_OAUTH_SETTINGS,
+        ),
+    ]
+
+    yield
+
+
 def get_oauth_module(integration: Integration) -> OAuthModule:
     """
     HELPER: Get the OAuthModule from the integration
@@ -97,8 +171,56 @@ def test_get_scopes(integration):
     Test if OAuthModule correctly returns the scopes defined in the integration settings
     """
     module = get_oauth_module(integration)
-    scopes = module._get_scopes()
-    assert set(scopes.split()) == {"test:scope", "another:scope"}
+
+    request = GetAuthorizationUrlRequest(
+        request=GetAuthorizationUrl(
+            client_id="test_client_id",
+            redirect_uri="https://example.com/callback",
+            state="test_state",
+            scopes=[],
+        ),
+        settings={"subdomain": "test"},
+    )
+
+    if isinstance(module.settings[0], OAuthSettings):
+        scopes = module._get_scopes(module.settings[0], request)
+        assert set(scopes.split()) == {"test:scope", "another:scope"}
+    else:
+        with pytest.raises(ConnectorError):
+            module._get_scopes(module.settings[0], request)  # type: ignore
+
+
+def test_get_scopes_with_scopes_callable(integration):
+    """
+    Test if OAuthModule correctly returns the scopes defined in the integration settings if its a callable
+    """
+
+    def get_scopes(args: AuthRequest) -> dict[str, str]:
+        return {
+            StandardCapabilityName.VALIDATE_CREDENTIALS: "test:scope another:scope",
+            StandardCapabilityName.LIST_ACCOUNTS: "test:scope another:scope",
+        }
+
+    module = get_oauth_module(integration)
+    if isinstance(module.settings[0], OAuthSettings):
+        module.settings[0].scopes = get_scopes
+
+    request = GetAuthorizationUrlRequest(
+        request=GetAuthorizationUrl(
+            client_id="test_client_id",
+            redirect_uri="https://example.com/callback",
+            state="test_state",
+            scopes=[],
+        ),
+        settings={"subdomain": "test"},
+    )
+
+    if isinstance(module.settings[0], OAuthSettings):
+        scopes = module._get_scopes(module.settings[0], request)
+        assert set(scopes.split()) == {"test:scope", "another:scope"}
+    else:
+        with pytest.raises(ConnectorError):
+            module._get_scopes(module.settings[0], request)  # type: ignore
 
 
 @pytest.mark.asyncio
@@ -111,12 +233,14 @@ async def test_dynamic_authorization_url(integration):
         settings = get_settings(args, integration.settings_model)
         return f"https://{settings.subdomain}.example.com/auth"
 
-    integration.oauth_settings.authorization_url = get_auth_url
+    module = get_oauth_module(integration)
+    if isinstance(module.settings[0], OAuthSettings):
+        module.settings[0].authorization_url = get_auth_url
 
     request = GetAuthorizationUrlRequest(
         request=GetAuthorizationUrl(
             client_id="test_client_id",
-            redirect_uri="https://example.com/callback",
+            redirect_uri="https://test.example.com/callback",
             state="test_state",
             scopes=["scope1"],
         ),
@@ -141,13 +265,15 @@ async def test_dynamic_token_url(integration):
         settings = get_settings(args, integration.settings_model)
         return f"https://{settings.subdomain}.example.com/token"
 
-    integration.oauth_settings.token_url = get_token_url
+    module = get_oauth_module(integration)
+    if isinstance(module.settings[0], OAuthSettings):
+        module.settings[0].token_url = get_token_url
 
     request = HandleAuthorizationCallbackRequest(
         request=HandleAuthorizationCallback(
             client_id="test_client_id",
             client_secret="test_secret",
-            redirect_uri_with_code="https://example.com/callback?code=test_code",
+            redirect_uri_with_code="https://test.example.com/callback?code=test_code",
         ),
         settings={"subdomain": "test"},
     )
@@ -175,10 +301,11 @@ async def test_get_authorization_url(integration):
     request = GetAuthorizationUrlRequest(
         request=GetAuthorizationUrl(
             client_id="test_client_id",
-            redirect_uri="https://example.com/callback",
+            redirect_uri="https://test.example.com/callback",
             state="test_state",
             scopes=["scope1", "scope2", "scope3"],
-        )
+        ),
+        settings={"subdomain": "test"},
     )
 
     response = await integration.capabilities[StandardCapabilityName.GET_AUTHORIZATION_URL](request)
@@ -186,11 +313,11 @@ async def test_get_authorization_url(integration):
     parsed_url = urlparse(response.response.authorization_url)
 
     assert parsed_url.scheme == "https"
-    assert parsed_url.netloc == "example.com"
+    assert parsed_url.netloc == "test.example.com"
     assert parsed_url.path == "/auth"
 
     assert "client_id=test_client_id" in parsed_url.query
-    assert "redirect_uri=https://example.com/callback" in parsed_url.query
+    assert "redirect_uri=https://test.example.com/callback" in parsed_url.query
     assert "state=test_state" in parsed_url.query
     assert "scope=scope1 scope2 scope3" in parsed_url.query
 
@@ -204,10 +331,11 @@ async def test_get_authorization_url_no_input_scopes(integration):
     request = GetAuthorizationUrlRequest(
         request=GetAuthorizationUrl(
             client_id="test_client_id",
-            redirect_uri="https://example.com/callback",
+            redirect_uri="https://test.example.com/callback",
             state="test_state",
             scopes=[],
-        )
+        ),
+        settings={"subdomain": "test"},
     )
 
     response = await integration.capabilities[StandardCapabilityName.GET_AUTHORIZATION_URL](request)
@@ -226,9 +354,9 @@ async def test_handle_authorization_callback(integration):
         request=HandleAuthorizationCallback(
             client_id="test_client_id",
             client_secret="test_client_secret",
-            redirect_uri_with_code="https://example.com/callback?code=test_code",
+            redirect_uri_with_code="https://test.example.com/callback?code=test_code",
         ),
-        include_raw_data=True,
+        settings={"subdomain": "test"},
     )
 
     mock_response = Response(
@@ -238,7 +366,7 @@ async def test_handle_authorization_callback(integration):
             "token_type": "Bearer",
             "refresh_token": "test_refresh_token",
         },
-        request=Request("POST", "https://example.com/token"),
+        request=Request("POST", "https://test.example.com/token"),
     )
 
     with patch.object(AsyncClient, "request", return_value=mock_response):
@@ -249,7 +377,6 @@ async def test_handle_authorization_callback(integration):
     assert response.response.access_token == "test_access_token"
     assert response.response.token_type == "bearer"
     assert response.response.refresh_token == "test_refresh_token"
-    assert response.raw_data is not None
 
 
 @pytest.mark.asyncio
@@ -263,7 +390,7 @@ async def test_handle_client_credentials_request(client_credentials_integration)
             client_secret="test_client_secret",
             scopes=["scope1", "scope2", "scope3"],
         ),
-        include_raw_data=True,
+        settings={"subdomain": "test"},
     )
 
     mock_response = Response(
@@ -272,7 +399,7 @@ async def test_handle_client_credentials_request(client_credentials_integration)
             "access_token": "test_access_token",
             "token_type": "Bearer",
         },
-        request=Request("POST", "https://example.com/token"),
+        request=Request("POST", "https://test.example.com/token"),
     )
 
     with patch.object(AsyncClient, "request", return_value=mock_response):
@@ -282,7 +409,6 @@ async def test_handle_client_credentials_request(client_credentials_integration)
 
     assert response.response.access_token == "test_access_token"
     assert response.response.token_type == "bearer"
-    assert response.raw_data is not None
 
 
 @pytest.mark.asyncio
@@ -296,7 +422,7 @@ async def test_refresh_access_token(integration):
             client_secret="test_client_secret",
             refresh_token="test_refresh_token",
         ),
-        include_raw_data=True,
+        settings={"subdomain": "test"},
     )
 
     mock_response = Response(
@@ -307,7 +433,7 @@ async def test_refresh_access_token(integration):
             "expires_in": 3600,
             "refresh_token": "new_refresh_token",
         },
-        request=Request("POST", "https://example.com/token"),
+        request=Request("POST", "https://test.example.com/token"),
     )
 
     with patch.object(AsyncClient, "request", return_value=mock_response):
@@ -318,7 +444,6 @@ async def test_refresh_access_token(integration):
     assert response.response.access_token == "new_access_token"
     assert response.response.token_type == "bearer"
     assert response.response.refresh_token == "new_refresh_token"
-    assert response.raw_data is not None
 
 
 @pytest.mark.asyncio
@@ -328,14 +453,16 @@ async def test_send_authorized_request_client_secret_basic(integration):
     when using client secret basic authentication (header auth)
     """
     module = get_oauth_module(integration)
-    module.settings.client_auth = ClientAuthenticationMethod.CLIENT_SECRET_BASIC
+    if isinstance(module.settings[0], OAuthSettings):
+        module.settings[0].client_auth = ClientAuthenticationMethod.CLIENT_SECRET_BASIC
 
     request = HandleAuthorizationCallbackRequest(
         request=HandleAuthorizationCallback(
             client_id="test_client_id",
             client_secret="test_client_secret",
-            redirect_uri_with_code="https://example.com/callback?code=test_code",
-        )
+            redirect_uri_with_code="https://test.example.com/callback?code=test_code",
+        ),
+        settings={"subdomain": "test"},
     )
 
     mock_response = Response(
@@ -345,14 +472,14 @@ async def test_send_authorized_request_client_secret_basic(integration):
             "token_type": "Bearer",
             "refresh_token": "test_refresh_token",
         },
-        request=Request("POST", "https://example.com/token"),
+        request=Request("POST", "https://test.example.com/token"),
     )
 
     mock_client = AsyncMock(spec=AsyncClient)
     mock_client.request.return_value = mock_response
 
     await module._send_authorized_request(
-        "https://example.com/token", "authorization_code", mock_client, request
+        "https://test.example.com/token", "authorization_code", mock_client, request
     )
 
     mock_client.request.assert_called_once()
@@ -369,16 +496,18 @@ async def test_send_authorized_request_query_request_type(integration):
     when using a request type with QUERY as the data parameter
     """
     module = get_oauth_module(integration)
-    module.settings.request_type = OAuthRequest(
-        method=RequestMethod.GET, data=RequestDataType.QUERY
-    )
+    if isinstance(module.settings[0], OAuthSettings):
+        module.settings[0].request_type = OAuthRequest(
+            method=RequestMethod.GET, data=RequestDataType.QUERY
+        )
 
     request = RefreshAccessTokenRequest(
         request=RefreshAccessToken(
             client_id="test_client_id",
             client_secret="test_client_secret",
             refresh_token="test_refresh_token",
-        )
+        ),
+        settings={"subdomain": "test"},
     )
 
     mock_response = Response(
@@ -388,14 +517,14 @@ async def test_send_authorized_request_query_request_type(integration):
             "token_type": "Bearer",
             "refresh_token": "test_refresh_token",
         },
-        request=Request("POST", "https://example.com/token"),
+        request=Request("POST", "https://test.example.com/token"),
     )
 
     mock_client = AsyncMock(spec=AsyncClient)
     mock_client.request.return_value = mock_response
 
     await module._send_authorized_request(
-        "https://example.com/token", "refresh_token", mock_client, request
+        "https://test.example.com/token", "refresh_token", mock_client, request
     )
 
     mock_client.request.assert_called_once()
@@ -413,14 +542,18 @@ async def test_send_authorized_request_json_request_type(integration):
     when using a request type with JSON as the data parameter
     """
     module = get_oauth_module(integration)
-    module.settings.request_type = OAuthRequest(method=RequestMethod.GET, data=RequestDataType.JSON)
+    if isinstance(module.settings[0], OAuthSettings):
+        module.settings[0].request_type = OAuthRequest(
+            method=RequestMethod.GET, data=RequestDataType.JSON
+        )
 
     request = RefreshAccessTokenRequest(
         request=RefreshAccessToken(
             client_id="test_client_id",
             client_secret="test_client_secret",
             refresh_token="test_refresh_token",
-        )
+        ),
+        settings={"subdomain": "test"},
     )
 
     mock_response = Response(
@@ -430,14 +563,14 @@ async def test_send_authorized_request_json_request_type(integration):
             "token_type": "Bearer",
             "refresh_token": "test_refresh_token",
         },
-        request=Request("GET", "https://example.com/token"),
+        request=Request("GET", "https://test.example.com/token"),
     )
 
     mock_client = AsyncMock(spec=AsyncClient)
     mock_client.request.return_value = mock_response
 
     await module._send_authorized_request(
-        "https://example.com/token", "refresh_token", mock_client, request
+        "https://test.example.com/token", "refresh_token", mock_client, request
     )
 
     mock_client.request.assert_called_once()
@@ -455,16 +588,18 @@ async def test_send_authorized_request_formdata_request_type(integration):
     when using a request type with FORMDATA as the data parameter
     """
     module = get_oauth_module(integration)
-    module.settings.request_type = OAuthRequest(
-        method=RequestMethod.GET, data=RequestDataType.FORMDATA
-    )
+    if isinstance(module.settings[0], OAuthSettings):
+        module.settings[0].request_type = OAuthRequest(
+            method=RequestMethod.GET, data=RequestDataType.FORMDATA
+        )
 
     request = RefreshAccessTokenRequest(
         request=RefreshAccessToken(
             client_id="test_client_id",
             client_secret="test_client_secret",
             refresh_token="test_refresh_token",
-        )
+        ),
+        settings={"subdomain": "test"},
     )
 
     mock_response = Response(
@@ -474,14 +609,14 @@ async def test_send_authorized_request_formdata_request_type(integration):
             "token_type": "Bearer",
             "refresh_token": "test_refresh_token",
         },
-        request=Request("POST", "https://example.com/token"),
+        request=Request("POST", "https://test.example.com/token"),
     )
 
     mock_client = AsyncMock(spec=AsyncClient)
     mock_client.request.return_value = mock_response
 
     await module._send_authorized_request(
-        "https://example.com/token", "refresh_token", mock_client, request
+        "https://test.example.com/token", "refresh_token", mock_client, request
     )
 
     mock_client.request.assert_called_once()
@@ -501,19 +636,19 @@ async def test_handle_authorization_callback_error(integration):
         request=HandleAuthorizationCallback(
             client_id="test_client_id",
             client_secret="test_client_secret",
-            redirect_uri_with_code="https://example.com/callback?code=test_code",
+            redirect_uri_with_code="https://test.example.com/callback?code=test_code",
         ),
-        include_raw_data=True,
+        settings={"subdomain": "test"},
     )
 
     mock_response = Response(
         400,
         json={"error": "invalid_grant", "error_description": "Invalid authorization code"},
-        request=Request("POST", "https://example.com/token"),
+        request=Request("POST", "https://test.example.com/token"),
     )
 
     with patch.object(AsyncClient, "request", return_value=mock_response):
-        with pytest.raises(HTTPStatusError):
+        with pytest.raises(ConnectorError):
             await integration.capabilities[StandardCapabilityName.HANDLE_AUTHORIZATION_CALLBACK](
                 request
             )
@@ -530,13 +665,14 @@ async def test_invalid_grant_type(integration):
             client_id="test_client_id",
             client_secret="test_client_secret",
             refresh_token="test_refresh_token",
-        )
+        ),
+        settings={"subdomain": "test"},
     )
 
     mock_client = AsyncMock(spec=AsyncClient)
     with pytest.raises(ValueError, match="Unsupported grant_type"):
         await module._send_authorized_request(
-            "https://example.com/token", "invalid_grant_type", mock_client, request
+            "https://test.example.com/token", "invalid_grant_type", mock_client, request
         )
 
 
@@ -549,9 +685,9 @@ async def test_oauth_credentials_conversion_error(integration):
         request=HandleAuthorizationCallback(
             client_id="test_client_id",
             client_secret="test_client_secret",
-            redirect_uri_with_code="https://example.com/callback?code=test_code",
+            redirect_uri_with_code="https://test.example.com/callback?code=test_code",
         ),
-        include_raw_data=True,
+        settings={"subdomain": "test"},
     )
 
     mock_response = Response(
@@ -560,7 +696,7 @@ async def test_oauth_credentials_conversion_error(integration):
             # Missing required fields
             "some_other_field": "value",
         },
-        request=Request("POST", "https://example.com/token"),
+        request=Request("POST", "https://test.example.com/token"),
     )
 
     with patch.object(AsyncClient, "request", return_value=mock_response):
@@ -576,15 +712,18 @@ async def test_handle_authorization_callback_pkce(integration):
     Test if OAuthModule correctly handles the authorization callback with PKCE
     """
     module = get_oauth_module(integration)
-    module.settings.pkce = True
+    if isinstance(module.settings[0], OAuthSettings):
+        module.settings[0].client_auth = ClientAuthenticationMethod.CLIENT_SECRET_POST
+        module.settings[0].pkce = True
 
     request = HandleAuthorizationCallbackRequest(
         request=HandleAuthorizationCallback(
             client_id="test_client_id",
             client_secret="test_client_secret",
-            redirect_uri_with_code="https://example.com/callback?code=test_code",
+            redirect_uri_with_code="https://test.example.com/callback?code=test_code",
             code_verifier="test_code_verifier",
-        )
+        ),
+        settings={"subdomain": "test"},
     )
 
     mock_response = Response(
@@ -594,14 +733,14 @@ async def test_handle_authorization_callback_pkce(integration):
             "token_type": "Bearer",
             "refresh_token": "test_refresh_token",
         },
-        request=Request("POST", "https://example.com/token"),
+        request=Request("POST", "https://test.example.com/token"),
     )
 
     mock_client = AsyncMock(spec=AsyncClient)
     mock_client.request.return_value = mock_response
 
     await module._send_authorized_request(
-        "https://example.com/token", "authorization_code", mock_client, request
+        "https://test.example.com/token", "authorization_code", mock_client, request
     )
 
     mock_client.request.assert_called_once()
@@ -609,7 +748,7 @@ async def test_handle_authorization_callback_pkce(integration):
     assert call_args.kwargs["data"] == {
         "grant_type": "authorization_code",
         "code": "test_code",
-        "redirect_uri": "https://example.com/callback",
+        "redirect_uri": "https://test.example.com/callback",
         "code_verifier": "test_code_verifier",  # must be included
         "client_id": "test_client_id",
         "client_secret": "test_client_secret",
@@ -622,15 +761,17 @@ async def test_get_authorization_url_pkce(integration):
     Test if OAuthModule correctly handles the authorization URL with PKCE
     """
     module = get_oauth_module(integration)
-    module.settings.pkce = True
+    if isinstance(module.settings[0], OAuthSettings):
+        module.settings[0].pkce = True
 
     request = GetAuthorizationUrlRequest(
         request=GetAuthorizationUrl(
             client_id="test_client_id",
-            redirect_uri="https://example.com/callback",
+            redirect_uri="https://test.example.com/callback",
             state="test_state",
             scopes=["scope1"],
-        )
+        ),
+        settings={"subdomain": "test"},
     )
 
     response = await integration.capabilities[StandardCapabilityName.GET_AUTHORIZATION_URL](request)
@@ -639,3 +780,74 @@ async def test_get_authorization_url_pkce(integration):
     query_params = parse_qs(parsed_url.query)
     assert "code_challenge" in query_params
     assert "code_challenge_method" in query_params
+
+
+@pytest.mark.asyncio
+async def test_check_oauth_module_settings_when_using_credentials(integration_with_credentials):
+    """
+    Test if OAuthModule correctly collects the settings from the credentials configs
+    """
+    module = get_oauth_module(integration_with_credentials)
+
+    assert isinstance(module.settings[0], OAuthConfig)
+    assert isinstance(module.settings[1], OAuthConfig)
+
+    assert module.settings[0].id == "test_credential"
+    assert module.settings[1].id == "test_credential_2"
+
+
+@pytest.mark.asyncio
+async def test_get_authorization_url_with_credentials(integration_with_credentials):
+    """
+    Test if OAuthModule correctly handles the authorization URL when configured with credentials
+    """
+    module = get_oauth_module(integration_with_credentials)
+    assert not isinstance(module.settings[0], OAuthSettings)
+    assert len(module.settings) == 2
+
+    request = GetAuthorizationUrlRequest(
+        request=GetAuthorizationUrl(
+            credential_id="test_credential",  # match
+            client_id="test_client_id",
+            redirect_uri="https://test.example.com/callback",
+            state="test_state",
+            scopes=["scope1", "scope2", "scope3"],
+        ),
+        settings={"subdomain": "test"},
+    )
+
+    response = await integration_with_credentials.capabilities[
+        StandardCapabilityName.GET_AUTHORIZATION_URL
+    ](request)
+
+    parsed_url = urlparse(response.response.authorization_url)
+    assert parsed_url.path == "/auth"
+
+    assert "client_id=test_client_id" in parsed_url.query
+    assert "redirect_uri=https://test.example.com/callback" in parsed_url.query
+    assert "state=test_state" in parsed_url.query
+    assert "scope=scope1 scope2 scope3" in parsed_url.query
+
+
+@pytest.mark.asyncio
+async def test_get_authorization_url_with_credentials_2(integration_with_credentials):
+    """
+    Test if OAuthModule correctly handles the authorization URL when configured with credentials
+    """
+    request = GetAuthorizationUrlRequest(
+        request=GetAuthorizationUrl(
+            credential_id="test_credential_2",  # match
+            client_id="test_client_id",
+            redirect_uri="https://test.example.com/callback",
+            state="test_state",
+            scopes=["scope1", "scope2", "scope3"],
+        ),
+        settings={"subdomain": "test"},
+    )
+
+    response = await integration_with_credentials.capabilities[
+        StandardCapabilityName.GET_AUTHORIZATION_URL
+    ](request)
+
+    parsed_url = urlparse(response.response.authorization_url)
+    assert parsed_url.path == "/auth2"  # parent credential settings are changed
