@@ -15,6 +15,9 @@ class TestScaffold:
                 Namespace(
                     directory=tmpdirname,
                     name="Test",
+                    tests_only=False,
+                    author_name=None,
+                    author_email=None,
                 )
             )
 
@@ -31,5 +34,8 @@ class TestScaffold:
                     Namespace(
                         directory=tmpdirname,
                         name="Test",
+                        tests_only=False,
+                        author_name=None,
+                        author_email=None,
                     )
                 )
